@@ -11,6 +11,7 @@ from kamzik3.devices.device import Device
 from kamzik3.snippets.snippetLogging import set_rotating_file_handler, set_file_handler
 from kamzik3.snippets.snippetsTimer import PreciseCallbackTimer
 
+
 class AttributeLogger(Device):
     # Logging interval in ms
     interval = 1e3
@@ -148,6 +149,12 @@ class AttributeLogger(Device):
             fp.write(header)
             fp.write("\n")
 
+    def write_line(self, line):
+        self.attribute_logger_handler.flush()
+        with open(self.log_file_name, "a+") as fp:
+            fp.write(line)
+            fp.write("\n")
+
     def start(self, flag=True):
         if flag:
             if self.logger_ticker is not None and self.is_status(STATUS_BUSY):
