@@ -96,6 +96,12 @@ class Device(Subject, YamlSerializable):
             self.attributes_sharing_map = {}
             self.attribute_attach_map = {}
             self._init_attributes()
+        # Check if device id is already registered in session and remove it if it's not our current Device
+        if self.device_id in kamzik3.session.devices and self != kamzik3.session.devices[self.device_id]:
+            kamzik3.session.devices[self.device_id].close()
+            kamzik3.session.devices[self.device_id] = None
+            del kamzik3.session.devices[self.device_id]
+        # Check if device is not registered in session
         if kamzik3.session is not None and self.device_id not in kamzik3.session.devices:
             self.set_session(kamzik3.session)
 
@@ -447,8 +453,9 @@ class Device(Subject, YamlSerializable):
 
         if propagate_change:
             value = attribute_object[attribute_list[-1]]
-
             if not is_equal(current_value, value) and kamzik3.session.publisher is not None:
+                if attribute_object[SAVE_CHANGE]:
+                    self.session.update_config(self.device_id, attribute_list, value)
                 header = "{}.{}".format(attribute_object.attribute_id, attribute_list[-1])
                 kamzik3.session.publisher.push_message(header, value, min_timeout=attribute_object.min_stream_timeout)
 
