@@ -193,7 +193,7 @@ class DeviceKohzu(DeviceSocket):
             readout_buffer = self.error_description.get(int(error_code), u"Undefined error")
             self.handle_command_error(command, readout_buffer)
             s = re.search("[A-Z]+([0-9]+)", command)
-            command = RESPONSE_ERROR.decode()
+            command = RESPONSE_ERROR
             if s is not None and s != -1:
                 channel = int(s.group(1)) - 1
                 self.notify((channel, ATTR_LAST_ERROR), readout_buffer)
