@@ -3,7 +3,7 @@ import os
 import shutil
 import time
 from collections import OrderedDict
-from threading import Lock
+from threading import RLock
 import oyaml as yaml
 import numpy as np
 import psutil
@@ -30,7 +30,7 @@ class DeviceSession(Device):
     LOG_GUI_OUTPUT_FILE = u"gui.log"
     LOG_MACRO_OUTPUT_FILE = u"macro.log"
     log_level = logging.INFO
-    config_lock = Lock()
+    config_lock = RLock()
 
     def __init__(self, device_id=None, config=None):
         kamzik3.session = self
