@@ -146,11 +146,6 @@ class DeviceTango(Device, DeviceProxy):
             self.exposed_methods.append((command_name, None))
 
         self.start_polling()
-        try:
-            self._expose_methods_to_clients()
-        except self.tango_exceptions as e:
-            self.handle_command_error(attribute, str(e))
-
         self._config_commands()
         self._config_attributes()
         self.set_status(STATUS_CONFIGURED)
@@ -158,8 +153,8 @@ class DeviceTango(Device, DeviceProxy):
 
     def start_polling(self):
         super().start_polling()
-        self.poll_attribute("State", self.config.get("base polling rate", 50))
-        self.poll_command(u"State", self.config.get("base polling rate", 50))
+        self.poll_attribute("State", self.config.get("base polling rate", 100))
+        self.poll_command(u"State", self.config.get("base polling rate", 100))
 
         for poll_attribute in self.config.get("poll_attributes", []):
             tango_attribute, timeout = poll_attribute
@@ -306,7 +301,7 @@ class DeviceTangoLambdaDetector(DeviceTango):
         Frames = int(float(device_units(self, "FrameNumbers", Frames).m))
         if Frames != self.get_value("FrameNumbers"):
             self.set_attribute(["FrameNumbers", VALUE], Frames)
-
+        time.sleep(1)
         self.StartAcq()
 
     @expose_method()
