@@ -4,11 +4,11 @@ from time import sleep
 
 import numpy as np
 
-from kamzik3.devices.dummy.deviceDummy import DeviceDummy
 from kamzik3 import DeviceError
 from kamzik3.constants import *
 from kamzik3.devices.device import Device
 from kamzik3.devices.deviceChannel import DeviceChannel
+from kamzik3.devices.dummy.deviceDummy import DeviceDummy
 from kamzik3.snippets.snippetsDecorators import expose_method
 
 
@@ -24,6 +24,7 @@ class DummyMotor(DeviceDummy):
         self.create_attribute(ATTR_CHANNELS, default_value=self.channels, readonly=True, default_type=np.uint16,
                               max_value=255)
 
+
 class DummyMotorChannel(DeviceChannel):
 
     def __init__(self, device, channel, device_id=None, config=None):
@@ -50,15 +51,15 @@ class DummyMotorChannel(DeviceChannel):
     def _init_attributes(self):
         DeviceChannel._init_attributes(self)
         self.create_attribute(ATTR_REFERENCED, default_value=True, readonly=True, default_type=np.bool)
-        self.create_attribute(ATTR_POSITION, default_value=0, default_type=np.int64, set_function=self._move_absolute,
+        self.create_attribute(ATTR_POSITION, default_value=0, default_type=np.float, set_function=self._move_absolute,
                               unit="nm", set_value_when_set_function=False, min_value=-1e9, max_value=1e9)
-        self.create_attribute(ATTR_POSITION_LOWER_LIMIT, default_value=-1e9, default_type=np.int64, min_value=-1e9,
+        self.create_attribute(ATTR_POSITION_LOWER_LIMIT, default_value=-1e9, default_type=np.float, min_value=-1e9,
                               max_value=1e9, unit="nm", set_function=self._set_lower_limit)
-        self.create_attribute(ATTR_POSITION_UPPER_LIMIT, default_value=1e9, default_type=np.int64, min_value=-1e9,
+        self.create_attribute(ATTR_POSITION_UPPER_LIMIT, default_value=1e9, default_type=np.float, min_value=-1e9,
                               max_value=1e9, unit="nm", set_function=self._set_upper_limit)
         self.create_attribute(ATTR_MAXIMUM_VELOCITY, default_value=1e5, default_type=np.uint64, min_value=10,
                               max_value=1e6, unit="nm/sec", set_function=self._set_maximum_velocity)
-        self.create_attribute(ATTR_VELOCITY, default_value=0, default_type=np.int64, min_value=-1e4, max_value=1e4,
+        self.create_attribute(ATTR_VELOCITY, default_value=0, default_type=np.float, min_value=-1e4, max_value=1e4,
                               unit="nm/sec")
 
     def subject_update(self, key, value, subject):
@@ -89,7 +90,7 @@ class DummyMotorChannel(DeviceChannel):
                 # Velocity in nm / 100ms
                 counter += 1
                 velocity = int(self.get_raw_value(ATTR_VELOCITY) / 10.)
-                new_position = self.get_raw_value(ATTR_POSITION) + velocity
+                new_position = int(self.get_raw_value(ATTR_POSITION) + velocity)
                 if direction == 1:
                     if new_position < setpoint:
                         self.set_raw_value(ATTR_POSITION, new_position)
