@@ -2,14 +2,16 @@ import numpy as np
 from PyQt5.QtCore import pyqtSlot, Qt
 from PyQt5.QtWidgets import QLabel, QWidget, QHBoxLayout
 
+from kamzik3 import GuiTypeError
 from kamzik3 import units
 from kamzik3.constants import *
-from kamzik3 import GuiTypeError
 from kamzik3.gui.attributeWidgets.attributeBoolWidget import AttributeBoolWidget
 from kamzik3.gui.attributeWidgets.attributeComboboxWidget import AttributeComboxWidget
 from kamzik3.gui.attributeWidgets.attributeFloatWidget import AttributeFloatWidget
+from kamzik3.gui.attributeWidgets.attributeImageWidget import AttributeImageWidget
 from kamzik3.gui.attributeWidgets.attributeIntWidget import AttributeIntWidget
 from kamzik3.gui.attributeWidgets.attributeStringWidget import AttributeStringWidget
+from kamzik3.gui.attributeWidgets.attributeTextWidget import AttributeTextWidget
 from kamzik3.gui.attributeWidgets.attributeUnsignedIntWidget import AttributeUnsignedIntWidget
 
 
@@ -35,6 +37,11 @@ class AttributeDisplayWidget(QWidget):
         if self.attribute[TYPE] == TYPE_LIST:
             self.attribute_widget = AttributeComboxWidget(self.attribute, self.config)
             self.attribute_widget.input_widget.activated.connect(self.on_value_set)
+        elif self.attribute[TYPE] == TYPE_ARRAY:
+            if self.attribute.get(DISPLAY) == IMAGE:
+                self.attribute_widget = AttributeImageWidget(self.attribute, self.config)
+            else:
+                self.attribute_widget = AttributeTextWidget(self.attribute, self.config)
         else:
             np_type = np.dtype(self.attribute[TYPE])
             if np_type == np.str:
