@@ -1,21 +1,18 @@
 import collections
-from threading import Lock
 
 import pint
 import pyqtgraph as pg
 from PyQt5.QtCore import pyqtSignal, pyqtSlot
 
-from kamzik3.snippets.snippetsYaml import YamlSerializable
-
 from kamzik3 import units
 from kamzik3.constants import *
+from kamzik3.snippets.snippetsYaml import YamlSerializable
 
 pg.setConfigOption(u'background', u'w')
 pg.setConfigOption(u'foreground', u"k")
 
 
 class AttributePlot(pg.PlotWidget, YamlSerializable):
-
     sig_repaint = pyqtSignal()
 
     def __init__(self, attribute, buffer_size, plot=None, parent=None, background='#fff', **kwargs):
@@ -38,11 +35,15 @@ class AttributePlot(pg.PlotWidget, YamlSerializable):
             self.setLabel(u"bottom", "point")
             self.showGrid(x=True, y=True, alpha=0.1)
             self.addItem(self.value_curve)
+            self.getAxis("left").enableAutoSIPrefix(False)
+            self.main_plot = self
         else:
             plot.setLabel(u"left", kwargs.get("left_label", ""), units=self.base_unit)
             plot.setLabel(u"bottom", "point")
             plot.showGrid(x=True, y=True, alpha=0.1)
             plot.addItem(self.value_curve)
+            plot.getAxis("left").enableAutoSIPrefix(False)
+            self.main_plot = plot
         self.sig_repaint.connect(self.slot_set_data)
 
     def yaml_mapping(self):
@@ -52,7 +53,9 @@ class AttributePlot(pg.PlotWidget, YamlSerializable):
 
     @pyqtSlot()
     def slot_set_data(self):
-        self.value_curve.setData(self.x_buffer, self.y_buffer)
+        if self.main_plot.isVisible():
+            if self.main_plot.parent() is None or self.main_plot.parent().isVisible():
+                self.value_curve.setData(self.x_buffer, self.y_buffer)
 
     def update(self, current_point=None, current_value=None):
         if current_point is None:
