@@ -1,4 +1,3 @@
-from PyQt5.QtCore import pyqtSlot
 from PyQt5.QtWidgets import QSizePolicy, QComboBox
 
 from kamzik3.constants import *
@@ -32,7 +31,3 @@ class AttributeComboxWidget(AttributeWidget):
 
     def get_widget_value(self):
         return self.input_widget.currentText()
-
-    @pyqtSlot("QString")
-    def set_unit(self, unit=None, reset=False):
-        return
