@@ -68,13 +68,15 @@ class LogView(Ui_Form, DeviceWidget):
 
     def refresh(self):
         self.slot_reset_all()
-
         filtered_columns = []
         for column, dtype in zip(self.pandas_dt.columns, self.pandas_dt.dtypes):
-            if dtype != "object":
-                filtered_columns.append(column)
             if dtype == "bool":
                 self.pandas_dt[column] = self.pandas_dt[column].astype(int, copy=False)
+            if self.pandas_dt[column].isnull().all():
+                # Ignore column if all values are NaN
+                continue
+            if dtype != "object":
+                filtered_columns.append(column)
         model = LogViewHeaderModel(filtered_columns)
         self.input_header_items.setModel(model)
         max_selected_rows = self.input_max_selected_rows.value()
@@ -112,8 +114,10 @@ class LogView(Ui_Form, DeviceWidget):
         window.setWindowTitle(win_title)
         window.setWidget(widget)
         window.master = master
-        y = self.pandas_dt[id].values
-        x = self.pandas_dt["Timestamp (sec)"].values
+        real_values_at = self.pandas_dt[id].notna()
+        y = self.pandas_dt[id][real_values_at].values
+        x = self.pandas_dt["Timestamp (sec)"][real_values_at].values
+
         widget.slot_set_data(x=x, y=y)
 
         return window
@@ -175,7 +179,8 @@ class LogView(Ui_Form, DeviceWidget):
         self.last_zoom_region = region
         for window in self.mdi_area.subWindowList():
             if not window.master:
-                window.widget().setXRange(*region, padding=0)
+                window.widget().setXRange(*region, padding=0, update=False)
+                window.widget().setClipToView(True)
                 x1, x2 = int(region[0]), int(region[1])
                 self.input_from_dt.setDateTime(QDateTime.fromTime_t(x1))
                 self.input_to_dt.setDateTime(QDateTime.fromTime_t(x2))
@@ -490,6 +495,9 @@ class LogView(Ui_Form, DeviceWidget):
             self.tile_sub_windows()
 
     def slot_export_to_pdf(self):
+        if self.input_windowed_plots.isChecked():
+            self.slot_set_windowed_plots(False)
+
         if len(self.mdi_area.subWindowList()) == 0:
             error_msg = "Export error: {}".format("Please select at least one plot to export.")
             self.logger.error(error_msg)
@@ -531,3 +539,34 @@ class LogView(Ui_Form, DeviceWidget):
                     error_msg = "Export error: {}".format(e)
                     self.logger.error(error_msg)
                     show_error_message(error_msg, self)
+
+            if self.input_windowed_plots.isChecked():
+                self.slot_set_windowed_plots(True)
+
+    def slot_export_to_csv(self):
+        if len(self.mdi_area.subWindowList()) == 0:
+            error_msg = "Export error: {}".format("Please select at least one plot to export.")
+            self.logger.error(error_msg)
+            show_error_message(error_msg, self)
+            return
+
+        options = QFileDialog.Options()
+        options |= QFileDialog.DontUseNativeDialog
+        extension_filter = "csv [*.csv] (*.csv)"
+        file_path, _ = QFileDialog.getSaveFileName(self, 'Set output file', "./{}".format("output.csv"),
+                                                   filter=extension_filter, initialFilter=extension_filter,
+                                                   options=options)
+        if file_path != "":
+            self.logger.info("Exporting plots to {}".format(file_path))
+            sel_mode = self.input_header_items.selectionModel()
+            columns = []
+
+            for item in sel_mode.selectedRows(0):
+                columns.append(item.data())
+            if self.last_zoom_region is None:
+                self.pandas_dt.to_csv(file_path, columns=columns, index=False)
+            else:
+                head = self.pandas_dt.columns
+                self.pandas_dt[(self.pandas_dt[head[1]] >= self.last_zoom_region[0]) & (
+                            self.pandas_dt[head[1]] <= self.last_zoom_region[1])].to_csv(file_path, columns=columns,
+                                                                                   index=False)
