@@ -1,6 +1,7 @@
 import os
 
 from PyQt5.QtCore import pyqtSignal
+from PyQt5.QtGui import QIcon
 from PyQt5.QtWidgets import QMainWindow, QFileDialog
 
 from kamzik3.constants import *
@@ -19,6 +20,7 @@ class LogViewWindow(QMainWindow, Ui_MainWindow):
         self.cache_directory = cache_directory
         QMainWindow.__init__(self)
         self.setupUi(self)
+        self.setWindowIcon(QIcon(":/icons/icons/log_icon_client.png"))
         self.setCentralWidget(view_widget)
         self.sig_task_update.connect(self.slot_task_update)
         self.loading_overlay = LoadingOverlayWidget(self)
@@ -38,7 +40,7 @@ class LogViewWindow(QMainWindow, Ui_MainWindow):
             if self.virtual_directory_device.get_value(ATTR_STATUS) in READY_DEVICE_STATUSES:
                 dialog = CustomOpenDialog(self.virtual_directory_device, parent=self)
                 if dialog.exec():
-                    requested_files, metadata = self.virtual_directory_device.prepare_files(dialog.selected_files)
+                    requested_files, metadata = self.virtual_directory_device.prepare_files(input_files=dialog.selected_files)
                     task_id = self.virtual_directory_device.sync_files(requested_files)
 
                     def callback(value):
