@@ -350,7 +350,7 @@ class SavedAttributesWidget(Ui_Form, DeviceWidget):
                             row.append(u"None")
                     except DeviceUnknownError:
                         row.append(u"None")
-                table.model().model_data["rows"].append(row)
+                table.model().model_data["rows"].insert(0, row)
                 table.model().layoutChanged.emit()
                 self.current_data[self.tab_groups.tabText(index)] = table.model().model_data
 
