@@ -74,12 +74,13 @@ class DeviceConnectionPoller(CallbackTimer):
 
     def check_devices_connection_timeout(self):
         for device in self.connecting_devices.copy():
-            if not device.connected and not device.connecting and device.allow_reconnect and (
-                    device.response_error or device.connection_error):
-                device.reconnect()
-            elif device.connecting_time >= device.connection_timeout:
-                if not device.allow_reconnect:
-                    self.remove_connecting_device(device)
+            # if not device.connected and not device.connecting and device.allow_reconnect and (
+            #         device.response_error or device.connection_error):
+            #     pass
+                # device.reconnect()
+            if device.connecting_time >= device.connection_timeout:
+                # if not device.allow_reconnect:
+                self.remove_connecting_device(device)
                 device.handle_connection_error(u"Connection timeout")
             elif device.connected:
                 self.remove_connecting_device(device)
@@ -89,8 +90,10 @@ class DeviceConnectionPoller(CallbackTimer):
         for device in self.connected_devices.copy():
             if not device.is_alive():
                 self.connected_devices.remove(device)
-                if device.allow_reconnect and (device.response_error or device.connection_error):
-                    self.add_connecting_device(device)
+                # if device.allow_reconnect and (device.response_error or device.connection_error):
+                #     self.add_connecting_device(device)
+                # if device.allow_reconnect and (device.response_error or device.connection_error):
+                #     self.add_connecting_device(device)
 
     def stop(self):
         self.logger.info(u"Stopping devices connection poller Thread")
