@@ -52,7 +52,7 @@ def show_info_message(message, parent=None):
     error_message.open()
 
 
-def show_question_dialog(question, title="", parent=None):
+def show_question_dialog(question, title="", parent=None, cancel=False):
     """
     Show dialog with two options. Yes or No.
     Return True or False.
@@ -61,9 +61,12 @@ def show_question_dialog(question, title="", parent=None):
     :param parent:
     :return: bool
     """
-    answer = QMessageBox.question(parent, title, question, buttons=QMessageBox.Yes | QMessageBox.No,
-                                  defaultButton=QMessageBox.No)
-    if answer == QMessageBox.Yes:
+    if cancel:
+        buttons = QMessageBox.Yes | QMessageBox.No | QMessageBox.Cancel
+    else:
+        buttons = QMessageBox.Yes | QMessageBox.No
+    answer = QMessageBox.question(parent, title, question, buttons=buttons, defaultButton=QMessageBox.No)
+    if answer in (QMessageBox.Yes, QMessageBox.Cancel):
         return answer
     else:
         return False
